@@ -42,3 +42,34 @@ chk_flob <- function(x, old = FALSE, x_name = NULL) {
   if (!vld_false(old)) class(exint) <- "exint"
   chk_exint(exint, x_name = paste("serialized element of", x_name))
 }
+
+#' Check slob
+#'
+#' Checks whether an object is a slob (serialized blob).
+#'
+#' @inheritParams chk::chk_flag
+#' @return `NULL`, invisibly. Called for the side effect of throwing an error
+#'   if the condition is not met.
+#' @seealso [flobr()] and [chk_slob()].
+#' @export
+#' @examples
+#' chk_slob(flobr:::slob_obj)
+chk_slob <- function(x, x_name = NULL) {
+  if (vld_slob(x)) {
+    return(invisible())
+  }
+
+  if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
+
+  chk_s3_class(x, "blob", x_name = x_name)
+  chk_scalar(x, x_name = x_name)
+
+  exint <- unlist(x)
+  exint <- try(unserialize(exint), silent = TRUE)
+  if (inherits(exint, "try-error")) {
+    abort_chk(x_name, " must be a blob of a serialized object.")
+  }
+
+  class(exint) <- "exint"
+  chk_exint(exint, x_name = paste("serialized element of", x_name))
+}
